recordStore.MarcIter

|  | ## Cheshire3 Object Model: Class MarcIter

Module recordStore :: Class MarcIter

## Class MarcIter
source code

Object Tree:

           object --+
                    |
    baseStore.BdbIter --+
                        |
                       MarcIter

Instance Methods

__init__(self, recStore)
next(self)
Inherited from `baseStore.BdbIter`: `__iter__`, `jump` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

recordStore |
documentStore |
workflow |
Inherited from `baseStore.BdbIter`: `cursor`, `cxn`, `nextData`, `store` Inherited from `object`: `__class__`

Method Details

### __init__(self, recStore) (Constructor) | source code
Overrides: baseStore.BdbIter.__init__

### next(self) | source code
Overrides: baseStore.BdbIter.next

Class Variable Details

    ### recordStore Value:
        None

    ### documentStore Value:
        None

    ### workflow Value:
        None